@@ -622,7 +622,32 @@ private:
     bool unsafeWipeAll_;
 };
 
-struct ControlHelper : BaseAPIHelper<ControlElement, Message::Control> {
+struct MoveHelper : BaseAPIHelper<MoveElement, Message::Move> {
+
+    MoveHelper(const eckit::URI& dest, bool removeSrc, int removeDelay, bool mpi, int threads) :
+        dest_(dest), removeSrc_(removeSrc), removeDelay_(removeDelay), mpi_(mpi), threads_(threads) {}
+    void encodeExtra(eckit::Stream& s) const {
+        s << dest_;
+        s << removeSrc_;
+        s << removeDelay_;
+        s << mpi_;
+        s << threads_;
+    }
+    static MoveElement valueFromStream(eckit::Stream& s, RemoteFDB*) {
+        MoveElement elem;
+        s >> elem;
+        return elem;
+    }
+
+private:
+    const eckit::URI& dest_;
+    bool removeSrc_;
+    int removeDelay_;
+    bool mpi_;
+    int threads_;
+};
+
+struct ControlHelper : BaseAPIHelper<StatusElement, Message::Control> {
 
     ControlHelper(ControlAction action, ControlIdentifiers identifiers) :
         action_(action),
@@ -731,6 +756,10 @@ ControlIterator RemoteFDB::control(const FDBToolRequest& request,
     return forwardApiCall(ControlHelper(action, identifiers), request);
 };
 
+MoveIterator RemoteFDB::move(const FDBToolRequest& request, const eckit::URI& dest, bool removeSrc, int removeDelay, bool mpi, int threads) {
+    return forwardApiCall(MoveHelper(dest, removeSrc, removeDelay, mpi, threads), request);
+}
+
 // -----------------------------------------------------------------------------------------------------
 
 // Here we do archive/flush related stuff
