@@ -26,9 +26,11 @@
 #include "fdb5/database/FieldLocation.h"
 #include "fdb5/database/Key.h"
 #include "fdb5/database/Index.h"
+#include "fdb5/api/helpers/ControlIterator.h"
 #include "fdb5/database/PurgeVisitor.h"
 #include "fdb5/database/StatsReportVisitor.h"
 #include "fdb5/database/WipeVisitor.h"
+#include "fdb5/database/MoveVisitor.h"
 #include "fdb5/rules/Schema.h"
 
 namespace fdb5 {
@@ -40,8 +42,8 @@ typedef std::map<Key, Index> IndexStore;
 class Catalogue {
 public:
 
-    Catalogue(const Key& key, const fdb5::Config& config)
-        : dbKey_(key), config_(config), buildByKey_(!key.empty()) {}
+    Catalogue(const Key& key, ControlIdentifiers controlIdentifiers, const fdb5::Config& config)
+        : dbKey_(key), config_(config), controlIdentifiers_(controlIdentifiers), buildByKey_(!key.empty()) {}
 
     virtual ~Catalogue() {}
 
@@ -49,7 +51,7 @@ public:
     virtual const Key& indexKey() const { NOTIMP; }
     const Config& config() const { return config_; }
 
-    std::unique_ptr<Store> buildStore(const Config& config);
+    std::unique_ptr<Store> buildStore();
     virtual const Schema& schema() const = 0;
 
     virtual bool selectIndex(const Key& key) = 0;
@@ -66,13 +68,11 @@ public:
     virtual StatsReportVisitor* statsReportVisitor() const = 0;
     virtual PurgeVisitor* purgeVisitor(const Store& store) const = 0;
     virtual WipeVisitor* wipeVisitor(const Store& store, const metkit::mars::MarsRequest& request, std::ostream& out, bool doit, bool porcelain, bool unsafeWipeAll) const = 0;
+    virtual MoveVisitor* moveVisitor(const Store& store, const metkit::mars::MarsRequest& request, const eckit::URI& dest, bool removeSrc, int removeDelay, bool mpi, int threads) const = 0;
 
     virtual void control(const ControlAction& action, const ControlIdentifiers& identifiers) const = 0;
 
-    virtual bool retrieveLocked() const = 0;
-    virtual bool archiveLocked() const = 0;
-    virtual bool listLocked() const = 0;
-    virtual bool wipeLocked() const = 0;
+    virtual bool enabled(const ControlIdentifier& controlIdentifier) const;
 
     virtual std::vector<fdb5::Index> indexes(bool sorted=false) const = 0;
 
@@ -104,7 +104,9 @@ protected: // methods
 protected: // members
 
     Key dbKey_;
-    const Config& config_;
+    Config config_;
+    ControlIdentifiers controlIdentifiers_;
+
 
 private: // members
 
@@ -122,7 +124,7 @@ public:
 class CatalogueWriter {
 public:
     virtual const Index& currentIndex() = 0;
-    virtual void archive(const Key& key, const FieldLocation* fieldLocation) = 0;
+    virtual void archive(const Key& key, std::unique_ptr<FieldLocation> fieldLocation) = 0;
     virtual void overlayDB(const Catalogue& otherCatalogue, const std::set<std::string>& variableKeys, bool unmount) = 0;
     virtual void index(const Key& key, const eckit::URI& uri, eckit::Offset offset, eckit::Length length) = 0;
     virtual void reconsolidate() = 0;
