@@ -46,6 +46,8 @@ public:
     virtual void flush() = 0;
     virtual void sync() = 0;
     virtual void visit(BTreeIndexVisitor& visitor) const = 0;
+    virtual void flock() = 0;
+    virtual void funlock() = 0;
 
 
     static const std::string& defaulType();
