@@ -21,6 +21,7 @@
 #include "fdb5/toc/TocCatalogueWriter.h"
 #include "fdb5/toc/TocFieldLocation.h"
 #include "fdb5/toc/TocIndex.h"
+#include "fdb5/io/LustreSettings.h"
 
 using namespace eckit;
 
@@ -38,7 +39,7 @@ TocCatalogueWriter::TocCatalogueWriter(const Key &key, const fdb5::Config& confi
 }
 
 TocCatalogueWriter::TocCatalogueWriter(const eckit::URI &uri, const fdb5::Config& config) :
-    TocCatalogue(uri.path(), config),
+    TocCatalogue(uri.path(), ControlIdentifiers{}, config),
     umask_(config.umask()) {
     writeInitRecord(TocCatalogue::key());
     TocCatalogue::loadSchema();
@@ -58,8 +59,7 @@ bool TocCatalogueWriter::selectIndex(const Key& key) {
 
         // Enforce lustre striping if requested
         if (stripeLustre()) {
-            LustreStripe stripe = stripeIndexLustreSettings();
-            fdb5LustreapiFileCreate(indexPath.localPath(), stripe.size_, stripe.count_);
+            fdb5LustreapiFileCreate(indexPath.localPath(), stripeIndexLustreSettings());
         }
 
         indexes_[key] = Index(new TocIndex(key, indexPath, 0, TocIndex::WRITE));
@@ -67,6 +67,7 @@ bool TocCatalogueWriter::selectIndex(const Key& key) {
 
     current_ = indexes_[key];
     current_.open();
+    current_.flock();
 
     // If we are using subtocs, then we need to maintain a duplicate index that doesn't get flushed
     // each step.
@@ -80,8 +81,7 @@ bool TocCatalogueWriter::selectIndex(const Key& key) {
 
             // Enforce lustre striping if requested
             if (stripeLustre()) {
-                LustreStripe stripe = stripeIndexLustreSettings();
-                fdb5LustreapiFileCreate(indexPath.localPath(), stripe.size_, stripe.count_);
+                fdb5LustreapiFileCreate(indexPath.localPath(), stripeIndexLustreSettings());
             }
 
             fullIndexes_[key] = Index(new TocIndex(key, indexPath, 0, TocIndex::WRITE));
@@ -89,6 +89,7 @@ bool TocCatalogueWriter::selectIndex(const Key& key) {
 
         currentFull_ = fullIndexes_[key];
         currentFull_.open();
+        currentFull_.flock();
     }
 
     return true;
@@ -128,7 +129,7 @@ void TocCatalogueWriter::index(const Key &key, const eckit::URI &uri, eckit::Off
         selectIndex(currentIndexKey_);
     }
 
-    Field field(new TocFieldLocation(uri, offset, length, Key()), currentIndex().timestamp());
+    Field field(TocFieldLocation(uri, offset, length, Key()), currentIndex().timestamp());
 
     current_.put(key, field);
 
@@ -199,14 +200,14 @@ void TocCatalogueWriter::reconsolidateIndexesAndTocs() {
         // We need to explicitly mask indexes in the master TOC
         if (!indexInSubtoc[i]) {
             Index& idx(readIndexes[i]);
-            TocRecord* r = new (&buf[combinedSize]) TocRecord(TocRecord::TOC_CLEAR);
+            TocRecord* r = new (&buf[combinedSize]) TocRecord(serialisationVersion().used(), TocRecord::TOC_CLEAR);
             combinedSize += roundRecord(*r, buildClearRecord(*r, idx));
             Log::info() << "Masking index: " << idx.location().uri() << std::endl;
         }
     }
 
     for (const std::string& subtoc_path : subtocs) {
-        TocRecord* r = new (&buf[combinedSize]) TocRecord(TocRecord::TOC_CLEAR);
+        TocRecord* r = new (&buf[combinedSize]) TocRecord(serialisationVersion().used(), TocRecord::TOC_CLEAR);
         combinedSize += roundRecord(*r, buildSubTocMaskRecord(*r, subtoc_path));
         Log::info() << "Masking sub-toc: " << subtoc_path << std::endl;
     }
@@ -226,6 +227,9 @@ const Index& TocCatalogueWriter::currentIndex() {
     return current_;
 }
 
+const TocSerialisationVersion& TocCatalogueWriter::serialisationVersion() const {
+    return TocHandler::serialisationVersion();
+}
 
 void TocCatalogueWriter::overlayDB(const Catalogue& otherCat, const std::set<std::string>& variableKeys, bool unmount) {
 
@@ -283,7 +287,14 @@ void TocCatalogueWriter::hideContents() {
     writeClearAllRecord();
 }
 
-void TocCatalogueWriter::archive(const Key& key, const FieldLocation* fieldLocation) {
+bool TocCatalogueWriter::enabled(const ControlIdentifier& controlIdentifier) const {
+    if (controlIdentifier == ControlIdentifier::List || controlIdentifier == ControlIdentifier::Retrieve) {
+        return false;
+    }
+    return TocCatalogue::enabled(controlIdentifier);
+}
+
+void TocCatalogueWriter::archive(const Key& key, std::unique_ptr<FieldLocation> fieldLocation) {
     dirty_ = true;
 
     if (current_.null()) {
@@ -291,7 +302,7 @@ void TocCatalogueWriter::archive(const Key& key, const FieldLocation* fieldLocat
         selectIndex(currentIndexKey_);
     }
 
-    Field field(fieldLocation, currentIndex().timestamp());
+    Field field(std::move(fieldLocation), currentIndex().timestamp());
 
     current_.put(key, field);
 
@@ -371,14 +382,14 @@ void TocCatalogueWriter::compactSubTocIndexes() {
             if (idx.dirty()) {
 
                 idx.flush();
-                TocRecord* r = new (&buf[combinedSize]) TocRecord(TocRecord::TOC_INDEX);
+                TocRecord* r = new (&buf[combinedSize]) TocRecord(serialisationVersion().used(), TocRecord::TOC_INDEX);
                 combinedSize += roundRecord(*r, buildIndexRecord(*r, idx));
             }
         }
 
         // And add the masking record for the subtoc
 
-        TocRecord* r = new (&buf[combinedSize]) TocRecord(TocRecord::TOC_CLEAR);
+        TocRecord* r = new (&buf[combinedSize]) TocRecord(serialisationVersion().used(), TocRecord::TOC_CLEAR);
         combinedSize += roundRecord(*r, buildSubTocMaskRecord(*r));
 
         // Write all of these  records to the toc in one go.
