@@ -12,21 +12,23 @@
 /// @author Emanuele Danovaro
 /// @date   August 2019
 
-#ifndef fdb5_TocCommon_H
-#define fdb5_TocCommon_H
+#pragma once
 
 #include "eckit/filesystem/PathName.h"
+#include "eckit/io/FileHandle.h"
+#include "eckit/thread/ThreadPool.h"
+#include "eckit/serialisation/Streamable.h"
 
 #include "fdb5/config/Config.h"
 #include "fdb5/database/Key.h"
+#include "fdb5/api/helpers/ControlIterator.h"
 
 namespace fdb5 {
 
 class TocCommon {
 public:
 
-    TocCommon(const eckit::
-              PathName& path);
+    TocCommon(const eckit::PathName& path);
     virtual ~TocCommon() {}
 
     static eckit::PathName findRealPath(const eckit::PathName& path);
@@ -41,8 +43,6 @@ public:
 protected: // methods
 
     virtual uid_t dbUID() const;
-    static bool stripeLustre();
-
 
 protected: // members
 
@@ -55,6 +55,28 @@ protected: // members
     mutable bool dirty_;
 };
 
-}
+// class for writing a chunk of the user buffer - used to perform multiple simultaneous writes
+class FileCopy : public eckit::ThreadPoolTask {
 
-#endif  // fdb5_TocCommon_H
+public:
+    FileCopy(const eckit::PathName& srcPath, const eckit::PathName& destPath, const std::string& fileName);    
+    FileCopy(eckit::Stream& s);
+
+    void encode(eckit::Stream&) const;
+
+    void execute() override;
+
+private: // methods
+
+    void print(std::ostream& s) const;
+    friend std::ostream& operator<<(std::ostream& s, const FileCopy& f) {
+        f.print(s);
+        return s;
+    }
+
+private:
+    eckit::PathName src_;
+    eckit::PathName dest_;
+};
+
+}
